@@ -2,7 +2,7 @@ package Perinci::Sub::ValidateArgs;
 
 # NOIFBUILT
 our $DATE = '2016-05-25'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -40,7 +40,7 @@ source string will be returned instead.
 
 _
         },
-        dies => {
+        die => {
             summary => 'Whether validator should die or just return '.
                 'an error message/response',
             schema => 'bool',
@@ -69,7 +69,9 @@ sub gen_args_validator {
 
     my $gencode_err = sub {
         my ($status, $term_msg) = @_;
-        if ($meta->{result_naked}) {
+        if ($args{die}) {
+            return "die $term_msg;";
+        } elsif ($meta->{result_naked}) {
             return "return $term_msg;";
         } else {
             return "return [$status, $term_msg];";
@@ -168,7 +170,7 @@ Perinci::Sub::ValidateArgs - Validate function arguments using schemas in Rinci
 
 =head1 VERSION
 
-This document describes version 0.006 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-25.
+This document describes version 0.007 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-25.
 
 =head1 SYNOPSIS
 
@@ -197,6 +199,17 @@ This document describes version 0.006 of Perinci::Sub::ValidateArgs (from Perl d
      ...
  }
 
+or, if you want the validator to die on failure:
+
+ ...
+ sub foo {
+     state $validator = gen_args_validator(die => 1);
+     my %args = @_;
+     $validator->(\%args);
+
+     ...
+ }
+
 =head1 DESCRIPTION
 
 This module (PSV for short) can be used to validate function arguments using
@@ -218,7 +231,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<dies> => I<bool>
+=item * B<die> => I<bool>
 
 Whether validator should die or just return an error message/response.
 
